# import libraries
import numpy as np
import pandas as pd
import requests
from scrapy import Selector

# Create a function that scrapes the content boxes from a page
def get_boxes(url):
    response = requests.get(url)
    sel = Selector(text=response.text)
    boxes = sel.css("a.component__link").getall()
    return boxes

# Create a function that scrapes the content from a box
def get_box_content(box, url):
    sel = Selector(text=box)
    box_title = sel.css("h2 > span ::text").get()
    box_subtitle = sel.css("h2").xpath("text()[1]").get()
    box_text = None
    box_image_url = sel.css("img ::attr(src)").get()

    if box_image_url is None:
        box_image_url = box_image_url
    else:
        box_image_url = "https://www.lse.ac.uk" + box_image_url

    box_image_alt = sel.css("img ::attr(alt)").get()

    department = "Management"
    page_title = get_page_title(url)
    page_url = url
    return department, page_title, page_url, box_title, box_subtitle, box_text, box_image_url, box_image_alt

# Create a function that creates a dataframe from the content
def make_df(department, page_title, page_url, box_title, box_subtitle, box_text, box_image_url, box_image_alt):
    df = pd.DataFrame({
        "department": [department],
        "page_title": [page_title],
        "page_url": [page_url],
        "box_title": [box_title],
        "box_subtitle": [box_subtitle],
        "box_text": [box_text],
        "box_image_url": [box_image_url],
        "box_image_alt": [box_image_alt]
    })
    return df

# Create a function that scrapes the title of a page from a given url
def get_page_title(url):
    response = requests.get(url)
    sel = Selector(text=response.text)
    page_title = sel.css("h1.stdPage__title ::text").get()
    if page_title is None:
        page_title = sel.css("h2.landingHeader__kind ::text").get()
    return page_title

# Create a function that combines the above functions to scrape a page of its content and return a dataframe
def get_page_df(url):
    boxes = get_boxes(url)
    page_df = pd.DataFrame()
    for box in boxes:
        department, page_title, page_url, box_title, box_subtitle, box_text, box_image_url, box_image_alt = get_box_content(box, url)
        df = make_df(department, page_title, page_url, box_title, box_subtitle, box_text, box_image_url, box_image_alt)
        page_df = pd.concat([page_df, df], ignore_index=True)
    return page_df